function [GRAD,DIV,LAP] = disc_op(n1,n2,bc)
%disc_op(n1,n2,bc) computes discret operator for the gradient, divergence 
%and laplacian. boundary condition can be choosen by the imput parameter bc:
%'n':neumann
%'d':dirichlet
%grid size h=1;

n=n1*n2;

switch bc
    
    case 'n'
        
        %---------- Laplace operator LAP ----------------------------------
        E = ones(n1,n2);
        e = reshape(E,n,1);
        
        E1 = E;
        E1(n1,:) = 0;
        e1a = reshape(E1,n,1);
        e1b = [0;e1a(1:n-1)];
        
        E2a = zeros(n1,n2);
        E2a(:,[1,n2]) = 1;
        E2b = zeros(n1,n2);
        E2b([1,n1],:) = 1;
        E2 = -4*E + E2a + E2b;
        e2=reshape(E2,n,1);
        
        LAP = spdiags([e e1a e2 e1b e], [-n1,-1,0,1,n1], n, n);
 
        %------------------------------------------------------------------
        
        
        %---------- Gradient operator GRAD --------------------------------
        E3=E;
        E3(n1,:)=0;
        e3a=reshape(E3,n,1);
        e3b=[0;e3a(1:n-1)];
    
        DX = spdiags([-e3a e3b], [0,1], n, n);
           
        E4a=E;
        E4b=E;
        E4a(:,n2)=0;
        E4b(:,1)=0;
        
        e4a=reshape(E4a,n,1);
        e4b=reshape(E4b,n,1);
        
        DY = spdiags([-e4a e4b], [0,n1], n, n);
        
        GRAD=[DX;DY];
        %------------------------------------------------------------------
        
        
        %---------- Divergency operator DIV -------------------------------
        DIV=-GRAD';
        %------------------------------------------------------------------
        
    case 'd'
        
       %---------- Laplace operator LAP -----------------------------------
        E = ones(n1,n2);
        e = reshape(E,n,1);
        
        E1 = E;
        E1(n1,:) = 0;
        e1a = reshape(E1,n,1);
        e1b = [0;e1a(1:n-1)];
        
        LAP = spdiags([e e1a -4*e e1b e], [-n1,-1,0,1,n1], n, n);     
        %------------------------------------------------------------------
        
        
        %---------- Gradient operator GRAD --------------------------------
               
        DX = spdiags([-e e1b], [0,1], n, n);  
        DY = spdiags([-e e], [0,n1], n, n);
        
        GRAD=[DX;DY];
        %--------------------------------------------------------------------------
        
     
        %---------- Divergency operator DIV ---------------------------------------
        DIV=-GRAD';
        %--------------------------------------------------------------------------
         
        
        
end



